
.. blogpost::
    :title: Operator CDist
    :keywords: onnxruntime, cdist
    :date: 2019-09-16
    :categories: onnx

    Notebooks :ref:`onnxpdistrst` shows how much slower
    an :epkg:`ONNX` implementation of function
    :epkg:`cdist`, from 3 to 10 times slower.
    One way to optimize the converted model is to
    create dedicated operator such as one for function
    :epkg:`cdist`. Tutorial :ref:`l-onnx-tutorial-optim`
    explains how to tell function :func:`to_onnx
    <mlprodict.onnx_conv.convert.to_onnx>` to use
    the custom operator `CDist`.
